@@ -36,9 +36,9 @@ def DDtheta_mocks(autocorr, nthreads, binfile,
 
 
     .. note:: This module only returns pair counts and not the actual
-       correlation function :math:`\\omega(\theta)`. See
+       correlation function :math:`\\omega(\\theta)`. See
        :py:mod:`Corrfunc.utils.convert_3d_counts_to_cf` for computing
-       :math:`\\omega(\theta)` from the pair counts returned.
+       :math:`\\omega(\\theta)` from the pair counts returned.
 
 
     Parameters
@@ -122,7 +122,7 @@ def DDtheta_mocks(autocorr, nthreads, binfile,
         Boolean flag to control output of informational messages
 
     output_thetaavg : boolean (default false)
-        Boolean flag to output the average ``\theta`` for each bin. Code will
+        Boolean flag to output the average ``\\theta`` for each bin. Code will
         run slower if you set this flag.
 
         If you are calculating in single-precision, ``thetaavg`` will
@@ -338,11 +338,11 @@ def DDtheta_mocks(autocorr, nthreads, binfile,
         import os
         os.remove(rbinfile)
 
-    results_dtype = np.dtype([(bytes_to_native_str(b'thetamin'), np.float),
-                              (bytes_to_native_str(b'thetamax'), np.float),
-                              (bytes_to_native_str(b'thetaavg'), np.float),
+    results_dtype = np.dtype([(bytes_to_native_str(b'thetamin'), np.float64),
+                              (bytes_to_native_str(b'thetamax'), np.float64),
+                              (bytes_to_native_str(b'thetaavg'), np.float64),
                               (bytes_to_native_str(b'npairs'), np.uint64),
-                              (bytes_to_native_str(b'weightavg'), np.float)])
+                              (bytes_to_native_str(b'weightavg'), np.float64)])
     results = np.array(extn_results, dtype=results_dtype)
 
     if not c_api_timer:
@@ -415,7 +415,7 @@ def find_fastest_DDtheta_mocks_bin_refs(autocorr, nthreads, binfile,
         Boolean flag to control output of informational messages
 
     output_thetaavg : boolean (default false)
-        Boolean flag to output the average ``\theta`` for each bin. Code will
+        Boolean flag to output the average ``\\theta`` for each bin. Code will
         run slower if you set this flag.
 
         If you are calculating in single-precision, ``thetaavg`` will
@@ -556,8 +556,8 @@ def find_fastest_DDtheta_mocks_bin_refs(autocorr, nthreads, binfile,
 
     dtype = np.dtype([(bytes_to_native_str(b'nRA'), np.int),
                       (bytes_to_native_str(b'nDEC'), np.int),
-                      (bytes_to_native_str(b'avg_time'), np.float),
-                      (bytes_to_native_str(b'sigma_time'), np.float)])
+                      (bytes_to_native_str(b'avg_time'), np.float64),
+                      (bytes_to_native_str(b'sigma_time'), np.float64)])
     all_runtimes = np.zeros(nperms, dtype=dtype)
     all_runtimes[:] = np.inf
 
