@@ -6,7 +6,10 @@ A set of utility routines
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 import sys
+import os
+import warnings
 from os.path import exists as file_exists
+
 import wurlitzer
 from contextlib import contextmanager
 
@@ -93,28 +96,29 @@ def convert_3d_counts_to_cf(ND1, ND2, NR1, NR2,
     >>> nbins = 10
     >>> bins = np.linspace(rmin, rmax, nbins + 1)
     >>> autocorr = 1
-    >>> DD_counts = DD(autocorr, nthreads, bins, X, Y, Z)
+    >>> DD_counts = DD(autocorr, nthreads, bins, X, Y, Z, boxsize=boxsize)
     >>> autocorr = 0
     >>> DR_counts = DD(autocorr, nthreads, bins,
     ...                X, Y, Z,
-    ...                X2=rand_X, Y2=rand_Y, Z2=rand_Z)
+    ...                X2=rand_X, Y2=rand_Y, Z2=rand_Z, boxsize=boxsize)
     >>> autocorr = 1
-    >>> RR_counts = DD(autocorr, nthreads, bins, rand_X, rand_Y, rand_Z)
+    >>> RR_counts = DD(autocorr, nthreads, bins, rand_X, rand_Y, rand_Z,
+    ...                boxsize=boxsize)
     >>> cf = convert_3d_counts_to_cf(N, N, rand_N, rand_N,
     ...                              DD_counts, DR_counts,
     ...                              DR_counts, RR_counts)
     >>> for xi in cf: print("{0:10.6f}".format(xi))
     ...                    # doctest: +NORMALIZE_WHITESPACE
-    22.769019
-     3.612709
-     1.621372
-     1.000969
-     0.691646
-     0.511819
-     0.398872
-     0.318815
-     0.255643
-     0.207759
+     22.769060
+      3.612701
+      1.621368
+      1.000967
+      0.691637
+      0.511813
+      0.398869
+      0.318813
+      0.255639
+      0.207754
 
     """
 
@@ -138,8 +142,8 @@ def convert_3d_counts_to_cf(ND1, ND2, NR1, NR2,
 
     nonzero = pair_counts['R1R2'] > 0
     if 'LS' in estimator or 'Landy' in estimator:
-        fN1 = np.float(NR1) / np.float(ND1)
-        fN2 = np.float(NR2) / np.float(ND2)
+        fN1 = np.float64(NR1) / np.float64(ND1)
+        fN2 = np.float64(NR2) / np.float64(ND2)
         cf = np.zeros(nbins)
         cf[:] = np.nan
         cf[nonzero] = (fN1 * fN2 * pair_counts['D1D2'][nonzero] -
@@ -244,40 +248,40 @@ def convert_rp_pi_counts_to_wp(ND1, ND2, NR1, NR2,
     >>> bins = np.linspace(rpmin, rpmax, nrpbins + 1)
     >>> autocorr = 1
     >>> DD_counts = DDrppi(autocorr, nthreads, pimax, bins,
-    ...                    X, Y, Z)
+    ...                    X, Y, Z, boxsize=boxsize)
     >>> autocorr = 0
     >>> DR_counts = DDrppi(autocorr, nthreads, pimax, bins,
     ...                    X, Y, Z,
-    ...                    X2=rand_X, Y2=rand_Y, Z2=rand_Z)
+    ...                    X2=rand_X, Y2=rand_Y, Z2=rand_Z, boxsize=boxsize)
     >>> autocorr = 1
     >>> RR_counts = DDrppi(autocorr, nthreads, pimax, bins,
-    ...                    rand_X, rand_Y, rand_Z)
+    ...                    rand_X, rand_Y, rand_Z, boxsize=boxsize)
     >>> wp = convert_rp_pi_counts_to_wp(N, N, rand_N, rand_N,
     ...                                 DD_counts, DR_counts,
     ...                                 DR_counts, RR_counts,
     ...                                 nrpbins, pimax)
     >>> for w in wp: print("{0:10.6f}".format(w))
     ...                    # doctest: +NORMALIZE_WHITESPACE
-    187.592199
-     83.059181
-     53.200599
-     40.389354
-     33.356371
-     29.045476
-     26.088133
-     23.628340
-     21.703961
-     20.153125
-     18.724781
-     17.433235
-     16.287183
-     15.443230
-     14.436193
-     13.592727
-     12.921226
-     12.330074
-     11.696364
-     11.208365
+    187.591897
+     83.059026
+     53.200243
+     40.389026
+     33.355778
+     29.044893
+     26.087995
+     23.627759
+     21.703655
+     20.152961
+     18.724304
+     17.432795
+     16.286740
+     15.443105
+     14.435802
+     13.592479
+     12.920796
+     12.329687
+     11.696258
+     11.208016
 
     """
 
@@ -792,8 +796,8 @@ def gridlink_sphere(thetamax,
     dec_binsize = dec_diff/ngrid_dec
 
     # Upper and lower limits of the declination bands
-    grid_dtype= np.dtype({'names':['dec_limit','ra_limit'],
-                          'formats':[(np.float, (2, )), (np.float, (2, ))]
+    grid_dtype = np.dtype({'names': ['dec_limit', 'ra_limit'],
+                          'formats': [(np.float64, (2, )), (np.float64, (2, ))]
     })
     if not link_in_ra:
         sphere_grid = np.zeros(ngrid_dec, dtype=grid_dtype)
@@ -1025,12 +1029,13 @@ def process_weights(weights1, weights2, X1, X2, weight_type, autocorr):
 @contextmanager
 def sys_pipes():
     '''
-    We can use the Wurlitzer package to redirect stdout and stderr
-    from the command line into a Jupyter notebook.  But if we're not
-    in a notebook, this isn't safe because we can't redirect stdout
-    to itself.  This function is a thin wrapper that checks if the
-    stdout/err streams are TTYs and enables output redirection
-    based on that.
+    In a Jupyter notebook, Python's ``sys.stdout`` and ``sys.stderr`` are redirected
+    so output ends up in cells.  But C extensions don't know about that!  Wurlitzer
+    uses os.dup2 to redirect fds 1 & 2 to the new location and restore them on return,
+    but will cause the output to hang if they were not already redirected.  It seems
+    we can compare Python's ``sys.stdout`` to the saved ``sys.__stdout__`` to tell
+    if redirection occurred.  We will also check if the output is a TTY as a safety
+    net, even though it is probably a subset of the preceeding check.
 
     Basic usage is:
 
@@ -1038,11 +1043,19 @@ def sys_pipes():
     ...    call_some_c_function()
 
     See the Wurlitzer package for usage of `wurlitzer.pipes()`;
-    see also https://github.com/manodeep/Corrfunc/issues/157.
+    see also https://github.com/manodeep/Corrfunc/issues/157,
+    https://github.com/manodeep/Corrfunc/issues/269.
     '''
-
-    kwargs = {'stdout':None if sys.stdout.isatty() else sys.stdout,
-              'stderr':None if sys.stderr.isatty() else sys.stderr }
+    
+    kwargs = {}
+    if sys.stdout.isatty() or (sys.stdout is sys.__stdout__):
+        kwargs['stdout'] = None
+    else:
+        kwargs['stdout'] = sys.stdout
+    if sys.stderr.isatty() or (sys.stderr is sys.__stderr__):
+        kwargs['stderr'] = None
+    else:
+        kwargs['stderr'] = sys.stderr
 
     # Redirection might break for any number of reasons, like
     # stdout/err already being closed/redirected.  We probably
@@ -1054,6 +1067,22 @@ def sys_pipes():
     except:
         yield
 
+
+def check_runtime_env():
+    '''
+    Detect any computing environment conditions that may cause Corrfunc
+    to fail, and inform the user if there is any action they can take.
+    '''
+
+    # Check if Cray hugepages is enabled at NERSC, which will crash
+    # C Python extensions due to a hugepages bug
+    if 'NERSC_HOST' in os.environ and os.getenv('HUGETLB_DEFAULT_PAGE_SIZE'):
+        warnings.warn('Warning: Cray hugepages has a bug that may crash '
+                      'Corrfunc. You might be able to fix such a crash with '
+                      '`module unload craype-hugepages2M` (see '
+                      'https://github.com/manodeep/Corrfunc/issues/245 '
+                      'for details)')
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
